summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoChild.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/KoChild.h')
-rw-r--r--lib/kofficecore/KoChild.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/lib/kofficecore/KoChild.h b/lib/kofficecore/KoChild.h
index b7285deb..fe345e2e 100644
--- a/lib/kofficecore/KoChild.h
+++ b/lib/kofficecore/KoChild.h
@@ -24,7 +24,7 @@
#include <koffice_export.h>
/**
* KoChild is an abstract base class that represents the tqgeometry
* associated with an embedded document. In general it handles its position
* relative to the embedded document's parent.
*
@@ -60,7 +60,7 @@ public:
virtual ~KoChild();
/**
* Sets a new tqgeometry for this child document.
* Use noEmit = true if you do not want the 'changed'-signal to be emitted
*/
void setGeometry( const TQRect &rect, bool noEmit = false );
@@ -74,7 +74,7 @@ public:
*
* @see #setGeometry
*/
- TQRect tqgeometry() const;
+ TQRect geometry() const;
/**
* @return the region of this child part relative to the
@@ -189,10 +189,10 @@ public:
/**
* @return the contents rectangle that is visible.
* This value depends on the scaling and the tqgeometry.
* This is the value that is passed to KoDocument::paintContent.
*
- * @see #xScaling #tqgeometry
+ * @see #xScaling #geometry
*/
virtual TQRect contentRect() const;
@@ -204,7 +204,7 @@ public:
virtual TQRegion frameRegion( const TQWMatrix& matrix = TQWMatrix(), bool solid = false ) const;
/**
* @return the frame tqgeometry including a border (6 pixels) as a point
* array with 4 points, one for each corner, transformed by given matrix.
*/
virtual TQPointArray framePointArray( const TQWMatrix &matrix = TQWMatrix() ) const;
@@ -234,11 +234,11 @@ public:
void unlock();
/**
* If the child is locked, tqgeometry changes
* (including scaling, rotation, ...) are not backed up.
*
* As long as this child is locked, the backed up
* tqgeometry state can be recovered with oldPointArray.
*
* @return true when this child is locked.
*
@@ -247,7 +247,7 @@ public:
bool locked() const;
/**
* @return the backed up tqgeometry transformed by given matrix.
*/
virtual TQPointArray oldPointArray( const TQWMatrix &matrix );
@@ -24,7 +24,7 @@
#include <koffice_export.h>
/**
- * KoChild is an abstract base class that represents the tqgeometry
+ * KoChild is an abstract base class that represents the geometry
* associated with an embedded document. In general it handles its position
* relative to the embedded document's parent.
@@ -60,7 +60,7 @@ public:
virtual ~KoChild();
/**
- * Sets a new tqgeometry for this child document.
+ * Sets a new geometry for this child document.
* Use noEmit = true if you do not want the 'changed'-signal to be emitted
*/
@@ -189,10 +189,10 @@ public:
/**
* @return the contents rectangle that is visible.
- * This value depends on the scaling and the tqgeometry.
+ * This value depends on the scaling and the geometry.
* This is the value that is passed to KoDocument::paintContent.
*
@@ -204,7 +204,7 @@ public:
virtual TQRegion frameRegion( const TQWMatrix& matrix = TQWMatrix(), bool solid = false ) const;
/**
- * @return the frame tqgeometry including a border (6 pixels) as a point
+ * @return the frame geometry including a border (6 pixels) as a point
* array with 4 points, one for each corner, transformed by given matrix.
*/
@@ -234,11 +234,11 @@ public:
void unlock();
/**
- * If the child is locked, tqgeometry changes
+ * If the child is locked, geometry changes
* (including scaling, rotation, ...) are not backed up.
*
@@ -234,11 +234,11 @@ public:
*
* As long as this child is locked, the backed up
- * tqgeometry state can be recovered with oldPointArray.
+ * geometry state can be recovered with oldPointArray.
*
* @return true when this child is locked.
@@ -247,7 +247,7 @@ public:
bool locked() const;
/**
- * @return the backed up tqgeometry transformed by given matrix.
+ * @return the backed up geometry transformed by given matrix.
*/
virtual TQPointArray oldPointArray( const TQWMatrix &matrix );